#
# spec file for package waf
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           waf
VCS: https://src.suse.de/SLFO-pool/waf#96e84dededa6af85fa5588480f9c7d2667f7106a4ea7538fc03a2c8bc28b6f51
Version:        2.0.26
Release:        160000.1.5
Summary:        The Waf build system
License:        BSD-3-Clause
Group:          Development/Tools/Building
URL:            https://waf.io
Source:         https://gitlab.com/ita1024/waf/-/archive/waf-%{version}/waf-waf-%{version}.tar.bz2
BuildRequires:  python3-base
BuildArch:      noarch

%description
Waf is a Python-based framework for configuring, compiling and installing applications.

%prep
%setup -q -n waf-waf-%{version}
find ./waflib -iname \*py -print -exec sed -i -e '1{ s/#!.*/#!foo/ }' '{}' \;

%build
python3 ./waf-light configure build
# Unpack waflib
python3 -c "import zipfile; z = zipfile.ZipFile('./zip/waflib.zip'); z.extractall(path='./zip/')"

cat <<EOF > ./waf.wrapper
#!/usr/bin/python3
import os, sys;
cwd = os.getcwd()
wafdir = "%{_datadir}/waf/"
sys.path.insert(0, wafdir)

if __name__ == '__main__':
	from waflib import Scripting
	Scripting.waf_entry_point(cwd, "%{version}", wafdir)
EOF

%install
install -m 755 -D waf.wrapper %{buildroot}%{_bindir}/waf
install -m 755 -d %{buildroot}%{_datadir}/waf/
cp -pR ./zip/waflib %{buildroot}%{_datadir}/waf/
%python3_fix_shebang

%check
export PYTHONDONTWRITEBYTECODE=1
export PYTHONPATH=%{buildroot}/%{_datadir}/waf/
%{buildroot}/%{_bindir}/waf -h

%files
%doc README.md
%{_bindir}/waf
%{_datadir}/waf

%changelog
* Fri Apr  5 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang macro, [bsc#1212476]
* Tue Dec 19 2023 bwiedemann@suse.com
- Do not write non-deterministic .pyc files in tests
* Mon Dec  4 2023 badboywj@gmail.com
- Update to 2.0.26
  * Improve "waf dist" - Support SOURCE_DATE_EPOCH
  * Detect Qt6 #2355
  * Haxe toolkit support #2352
  * Updated the project's gpg key
* Thu Jan  5 2023 dmueller@suse.com
- update to 2.0.25:
  * Fix invalid characters returned by find_program #2397
  * Prepare for distutils removal (Python 3.12 regression) #2402
  * Improve cp65001 compat in cpython < 3.3 #2346
  * Add Fujitsu Fortran compiler detection on ARM64FX #2348
  * Support multiple Sphinx output formats #2344
  * Improve PyQt5 detection #2343
  * Add asynchronous wafcache uploads
* Mon Jun 27 2022 stefan.bruens@rwth-aachen.de
- Initial package version (2.0.24)
